import Vue from 'vue'
import Vuex from 'vuex'
import { getUser, logout, getAllSetting } from '@/api/base'

Vue.use(Vuex)

const store = new Vuex.Store({
  state: {
    user: {},
    stepIndex: 0,
    stepResult: [],
    allSettings: {}
  },
  mutations: {
    setUser(state, user) {
      state.user = user
    },
    saveStepIndex(state, stepIndex) {
      state.stepIndex = stepIndex
    },

    setStepResult(state, stepResult) {
      state.stepResult = stepResult
    },
    setAllSettings(state, allSettings) {
      state.allSettings = allSettings
    }
  },
  actions: {
    // 获取用户信息
    getUser({ commit }) {
      getUser().then(response => {
        commit('setUser', response.data)
      })
    },
    // 退出登录
    logout({ commit }) {
      return logout().then(response => {
        commit('setUser', {})
        return response
      })
    },
    async checkLogin({ commit }) {
      const isLogin = await getUser()
        .then(response => {
          if (response.code === 0) {
            window.localStorage.userInfo = JSON.stringify(response.data)
            store.dispatch('getAllSetting')
            commit('setUser', response.data)
            return true
          } else {
            commit('setUser', {})
            return false
          }
        })
        .catch(() => {
          commit('setUser', {})
          return false
        })
      return isLogin
    },
    // 获取所有项目列表
    getAllSetting({ commit }) {
      getAllSetting().then(res => {
        window.localStorage.allSetting = JSON.stringify(res.data)
        commit('setAllSettings', res.data)
      })
    }
  }
})
export default store
