import axios from 'axios'
// import queryString from 'query-string'
import { Message } from 'element-ui'
import router from '../router'
// import store from '../store'
import qs from 'qs'

const httpRequest = axios.create({
  timeout: 60000,
  withCredentials: true,
  headers: { 'Content-Type': 'application/x-www-form-urlencoded' }
})

// 请求拦截
httpRequest.interceptors.request.use(
  function (config) {
    if (config.headers['Content-Type'] === 'application/x-www-form-urlencoded') {
      config.data = qs.stringify(config.data)
    }
    if (config.headers['Content-Type'] === 'multipart/form-data') {
      const formData = new window.FormData()
      for (const key in config.data) {
        formData.append(key, config.data[key])
      }
      config.data = formData
    }
    return config
  },
  function (error) {
    return Promise.reject(error)
  }
)

// 响应拦截
httpRequest.interceptors.response.use(
  function (response) {
    const { data } = response
    if (data.code && data.code !== 999) {
      // 未登录
      if (data.code === 4001) {
        window.location.href = `${import.meta.env.VITE_LOGIN_URL}`
      }
      // 未登录
      if (data.code === 1) {
        // window.location.href = `${import.meta.env.VITE_LOGIN_URL}`
        return data
      }
      // 没有权限
      if (data.code === 4008 || data.code === 5018) {
        router.push('/401')
      }
      // 题库分类修改
      if (data.code === 403) {
        Message({ message: '没有操作权限', type: 'error' })
        return data
      }
      Message({ message: data.message, type: 'error' })
      return Promise.reject(data)
    }
    return data
  },
  function (error) {
    if (error.response) {
      const { status, message } = error.response.data
      // 未登录
      if (status === 403) {
        window.location.href = `${import.meta.env.VITE_LOGIN_URL}`
      } else {
        Message.error(message || error.response.data)
      }
    } else {
      console.log(error)
    }
    return Promise.reject(error.response || error)
  }
)

export default httpRequest
